part of 'login_bloc.dart';

abstract class LoginEvent extends Equatable {
  const LoginEvent();

  @override
  List<Object?> get props => [];
}

class LoginSubmitted extends LoginEvent {
  final String emailAddress;
  final String password;
  final bool rememberMe;

  const LoginSubmitted({
    required this.emailAddress,
    required this.password,
    this.rememberMe = false,
  });

  @override
  List<Object?> get props => [emailAddress, password, rememberMe];
}

class LoginPasswordVisibilityToggled extends LoginEvent {
  const LoginPasswordVisibilityToggled();
}

class LoginRememberMeToggled extends LoginEvent {
  final bool value;
  const LoginRememberMeToggled(this.value);

  @override
  List<Object?> get props => [value];
}

class LoginEmailErrorToggled extends LoginEvent {
  final bool show;
  const LoginEmailErrorToggled(this.show);

  @override
  List<Object?> get props => [show];
}

class LoginPasswordErrorToggled extends LoginEvent {
  final bool show;
  const LoginPasswordErrorToggled(this.show);

  @override
  List<Object?> get props => [show];
}